@@ -5,7 +5,7 @@
 =head1 Name
 
  Math::Intersection::Circle::Line - Find the points at which circles and lines
- intersect.
+ intersect and the area of these intersections.
 
 =head1 Synopsis
 
@@ -96,6 +96,13 @@ sub near4($$$$;$$$$)
   near($D//0, $d)
  }
 
+#-------------------------------------------------------------------------------
+# Trigonometric functions
+#-------------------------------------------------------------------------------
+
+sub 𝝿 {4*atan2(1,1)}                                                            # Pi
+#sub asin { atan2($_[0], sqrt(1 - $_[0] * $_[0])) }
+
 #-------------------------------------------------------------------------------
 # Length of a vector
 #-------------------------------------------------------------------------------
@@ -129,13 +136,15 @@ sub rotate90AroundMidPoint($$$$)
  }
 
 #-------------------------------------------------------------------------------
-# Intersection of a circle A, with a circle B.
+# 𝗜ntersection of a circle A, with a circle B.
 #
-# Known: coordinates of the centre and radius of each circle  x, y, r, 𝘅, 𝘆, 𝗿
+# 𝗞nown: coordinates of the centre and radius of each circle  x, y, r, 𝘅, 𝘆, 𝗿
+#
+# 𝗙ind: the coordinates of the points at which the circles intersect.
 #
 # Two different circles either do not intersect, or if they do, they intersect
 # at one or two points.  If they intersect at two points, the intersections are
-# mirror images of each othe in the line that connects the centres of the two
+# mirror images of each other in the line that connects the centres of the two
 # circles.
 #
 # Let 𝗟 be the line joining the two centres with length 𝗹 = a + 𝗮 where a is the
@@ -160,6 +169,8 @@ sub intersectionCircles(&$$$$$$)
       $x, $y, $r,                                                               # First circle centre, radius
       $𝘅, $𝘆, $𝗿) = @_;                                                         # Second circle centre, radius
 
+#  near($r) and confess "Radius of first circle is too small!";
+#  near($𝗿) and confess "Radius of second circle is too small!";
   near($x, $𝘅) and near($y, $𝘆) and near($r, $𝗿) and                            # Complain if the two circles are in fact the same circle within the definition of nearness
     confess "Duplicate circles!  Please provide two distinct circles.";
 
@@ -179,10 +190,46 @@ sub intersectionCircles(&$$$$$$)
  }
 
 #-------------------------------------------------------------------------------
-# Position on a line closest to a specified point
+# 𝗔rea of intersection of two circles.
 #
-# Known: two points on the line 𝗟 such that: 𝗹 = (𝘅, 𝘆), 𝕝 = (𝕩, 𝕪) and the
-# specified point 𝗽 = (x, y).  We want to find 𝗰 the point on 𝗟 closest to 𝗽.
+# 𝗞nown: two circles specified by ($x, $y, $r) and ($𝘅, $𝘆, $𝗿)
+#
+# 𝗙ind: the area of intersection expressed as a fraction of the area
+# of the smaller circle
+#
+# The area of a triangle is (base * height) / 2, the area of a slice is 𝝰𝗿𝗿/2
+# where 𝝰 is the angle of a slice.
+#-------------------------------------------------------------------------------
+
+sub intersectionCirclesArea(&$$$$$$)
+ {my ($sub,                                                                     # Sub routine to process area
+      $x, $y, $r,                                                               # First circle centre, radius
+      $𝘅, $𝘆, $𝗿) = @_;                                                         # Second circle centre, radius
+
+  near($r) and confess "Radius of first circle is too small!";
+  near($𝗿) and confess "Radius of second circle is too small!";
+  my $l = vectorLength($𝘅 - $x, $𝘆 - $y);                                       # Distance between centres
+  return &$sub(0) if $l >= $r + $𝗿;                                             # The circles are too far apart to overlap
+  my $𝕣 = $r < $𝗿 ? $r : $𝗿;                                                    # Radius of smaller circle
+  return &$sub(1) if $l <= abs($r - $𝗿);                                        # The larger circle overlaps the smaller circle completely
+
+  intersectionCircles
+   {my ($X, $Y, $𝗫, $𝗬) = @_;
+    my $h = vectorLength($X - $𝗫, $Y - $𝗬) / 2;                                 # Height of triangles
+    my $R = sqrt($r**2 - $h**2);                                                # Base of triangle in first circle
+    my $𝗥 = sqrt($𝗿**2 - $h**2);                                                # Base of triangle in second circle
+#   &$sub(($r**2*asin($h/$r) + $𝗿**2*asin($h/$𝗿) - $h*($R+$𝗥))/(𝝿()*$𝕣**2))     # Fraction of smaller circle overlapped
+    &$sub(($r**2*atan2($h, $R) + $𝗿**2*atan2($h, $𝗥) - $h*($R+$𝗥))/(𝝿()*$𝕣**2)) # Fraction of smaller circle overlapped
+   } $x, $y, $r, $𝘅, $𝘆, $𝗿;
+ }
+
+#-------------------------------------------------------------------------------
+# 𝗣osition on a line closest to a specified point
+#
+# 𝗞nown: two points on the line 𝗟 such that: 𝗹 = (𝘅, 𝘆), 𝕝 = (𝕩, 𝕪) and the
+# specified point 𝗽 = (x, y).
+#
+# 𝗙ind 𝗰 the point on 𝗟 closest to 𝗽.
 #
 # A circle with centre 𝗹 through 𝗽 will intersect a circle with centre 𝕝 through
 # 𝗽 at 𝗾. 𝗰 is then the average of 𝗽 and 𝗾.
@@ -205,11 +252,11 @@ sub intersectionLinePoint(&$$$$$$)
  }
 
 #-------------------------------------------------------------------------------
-# Intersection of two lines
+# 𝗜ntersection of two lines
 #
-# Given two lines l specified by two points 𝗹 = (𝘅, 𝘆),  𝕝 = (𝕩, 𝕪) and
-#                 L specified by two points 𝗟 = (𝗫, 𝗬), 𝕃 = (𝕏, 𝕐)
-# We want to find 𝗰 the point where the two lines intersect (if they do)
+# 𝗞nown: two lines l specified by two points 𝗹 = (𝘅, 𝘆),  𝕝 = (𝕩, 𝕪) and
+#                  L specified by two points 𝗟 = (𝗫, 𝗬), 𝕃 = (𝕏, 𝕐)
+# 𝗙ind 𝗰 the point where the two lines intersect (if they do)
 #
 # Let the closest point to 𝗟 on l be 𝗮 and the closest point to 𝗮 on 𝗟 by 𝗯.
 # L𝗮𝗯 is similar to L𝗮𝗰.
@@ -244,12 +291,14 @@ sub intersectionLines(&$$$$$$$$)
      } $𝗫, $𝗬,  $𝕏, $𝕐,  $𝗮x, $𝗮y;                                              # Find 𝗯 on second line
    } $𝘅, $𝘆,  $𝕩, $𝕪,   $𝗫, $𝗬;                                                 # Find 𝗮 on first line
  }
+
 #-------------------------------------------------------------------------------
-# Intersection of a circle with a line
+# 𝗜ntersection of a circle with a line
 #
-# Given a circle specified by its centre: (x, y), and radius: r
-# and a line that passes through points: ($𝘅, $𝘆) and ($𝕩, $𝕪)
-# find the two points at which the line crosses the circle or the single point
+# 𝗞nown: a circle specified by its centre (x, y), and radius (r)
+# and a line that passes through points: ($𝘅, $𝘆) and ($𝕩, $𝕪).
+#
+# 𝗙ind: the two points at which the line crosses the circle or the single point
 # at which the line touches the circle or report that there are no points in
 # common.
 #
@@ -287,9 +336,36 @@ sub intersectionCircleLine(&$$$$$$$)
  }
 
 #-------------------------------------------------------------------------------
-# Intersection of a circle with a line - alternative method to confirm tests
+# 𝗔rea of intersection of a circle with a line
 #
-# Known 𝘅, 𝘆, r, X, x, Y, y find l,t
+# 𝗞nown: a circle specified by its centre (x, y), and radius (r)
+# and a line that passes through points: ($𝘅, $𝘆) and ($𝕩, $𝕪).
+#
+# 𝗙ind: the area of the smallest lune as a fraction of the area of the circle
+#
+#-------------------------------------------------------------------------------
+
+sub intersectionCircleLineArea(&$$$$$$$)
+ {my ($sub,                                                                     # Sub routine to process area
+      $x, $y, $r,                                                               # Circle centre, radius
+      $𝘅, $𝘆, $𝕩, $𝕪) = @_;                                                     # Line goes through these two points
+
+  near($𝘅, $𝕩) and near($𝘆, $𝕪) and confess "Points on line are too close!";
+  near($r) and confess "Radius is too small!";
+
+  intersectionCircleLine
+   {return &$sub(0) if @_ < 4;
+	  my ($X, $Y, $𝗫, $𝗬) = @_;                                                   # Intersection points
+    my $h = vectorLength($X - $𝗫, $Y - $𝗬) / 2;                                 # Height of triangle
+    my $w = sqrt($r**2 - $h**2);                                                # Base of triangle
+    &$sub(($r**2*atan2($h, $w) - $h*$w)/(𝝿()*$r**2))                             # Area of smallest lune as a fraction of circle
+   } $x, $y, $r, $𝘅, $𝘆, $𝕩, $𝕪;
+ }
+
+#-------------------------------------------------------------------------------
+# 𝗜ntersection of a circle with a line - alternative method to confirm tests
+#
+# 𝗞nown: 𝘅, 𝘆, r, X, x, Y, y  𝗙ind: l,t
 #
 # Circle(t)    Line(l) from (X,Y) to (x,y)
 # 𝘅+𝗿*cos(t) = X+l*(X-x)
@@ -301,7 +377,7 @@ sub intersectionCircleLine(&$$$$$$$)
 # rr         = 𝕏𝕏 + ll𝗫𝗫 + l2𝕏𝗫  + 𝕐𝕐 + ll𝗬𝗬 + l2𝕐𝗬
 # 0          = ll(a = 𝗫𝗫 + 𝗬𝗬) + l(b = 2(𝕏𝗫  + 𝕐𝗬)) + (c = 𝕏𝕏 + 𝕐𝕐 - rr)
 #
-# Quadratic equation axx+bx+c has roots:
+# 𝗤uadratic equation axx+bx+c has roots:
 #
 # x1, x2  = -b/2a +- sqrt(bb-4ac)/2a
 #-------------------------------------------------------------------------------
@@ -345,14 +421,15 @@ require Exporter;
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION);
 
 @ISA       = qw(Exporter);
-@EXPORT    = qw(intersectionCircles intersectionCircleLine intersectionLines intersectionLinePoint);
+@EXPORT    = qw(intersectionCircles intersectionCirclesArea intersectionCircleLine intersectionCircleLineArea intersectionLines intersectionLinePoint);
 @EXPORT_OK = qw(midPoint near near2 near4 rotate90CW rotate90CCW rotate90AroundMidPoint vectorLength);
 $EXPORT_TAGS{all} = [@EXPORT, @EXPORT_OK];
-$VERSION   = '1.002'; # Thursday 20 Aug 2015
+$VERSION   = '1.003'; # Sunday 30 Aug 2015
 
 =head1 Description
 
- Find the points at which circles and lines intersect.
+ Find the points at which circles and lines intersect and the area of these
+ intersections.
 
  Fast and easy to use these functions are written in 100% Pure Perl.
 
@@ -372,7 +449,24 @@ $VERSION   = '1.002'; # Thursday 20 Aug 2015
  where (𝘅, 𝘆) are the coordinates of the centre of the circle and (𝗿) is its
  radius.
 
- Returns what ever is returned by 𝘀𝘂𝗯.
+ Returns whatever is returned by 𝘀𝘂𝗯.
+
+=head2 intersectionCirclesArea 𝘀𝘂𝗯 circle1, circle2
+
+ Find the area of overlap of two circles expressed as a fraction of the area of
+ the smallest circle. The fractional area is expressed as a number between 0
+ and 1.
+
+ 𝘀𝘂𝗯 specifies a subroutine to be called with the fractional area.
+
+ A circle is specified by supplying a list of three numbers:
+
+  (𝘅, 𝘆, 𝗿)
+
+ where (𝘅, 𝘆) are the coordinates of the centre of the circle and (𝗿) is its
+ radius.
+
+ Returns whatever is returned by 𝘀𝘂𝗯.
 
 =head2 intersectionCircleLine 𝘀𝘂𝗯 circle, line
 
@@ -395,7 +489,30 @@ $VERSION   = '1.002'; # Thursday 20 Aug 2015
 
  where (x, y) and (𝘅, 𝘆) are the coordinates of two points on the line.
 
- Returns what ever is returned by 𝘀𝘂𝗯.
+ Returns whatever is returned by 𝘀𝘂𝗯.
+
+=head2 intersectionCircleLineArea 𝘀𝘂𝗯 circle, line
+
+ Find the fractional area of a circle occupied by a lune produced by an
+ intersecting line. The fractional area is expressed as a number
+ between 0 and 1.
+
+  𝘀𝘂𝗯 specifies a subroutine to be called with the fractional area.
+
+ A circle is specified by supplying a list of three numbers:
+
+  (𝘅, 𝘆, 𝗿)
+
+ where (𝘅, 𝘆) are the coordinates of the centre of the circle and (𝗿) is its
+ radius.
+
+ A line is specified by supplying a list of four numbers:
+
+  (x, y, 𝘅, 𝘆)
+
+ where (x, y) and (𝘅, 𝘆) are the coordinates of two points on the line.
+
+ Returns whatever is returned by 𝘀𝘂𝗯.
 
 =head2 intersectionLines 𝘀𝘂𝗯 line1, line2
 
@@ -413,7 +530,7 @@ $VERSION   = '1.002'; # Thursday 20 Aug 2015
 
  where (x, y) and (𝘅, 𝘆) are the coordinates of two points on the line.
 
- Returns what ever is returned by 𝘀𝘂𝗯.
+ Returns whatever is returned by 𝘀𝘂𝗯.
 
 =head2 intersectionLinePoint 𝘀𝘂𝗯 line, point
 
@@ -434,7 +551,7 @@ $VERSION   = '1.002'; # Thursday 20 Aug 2015
 
  where (𝘅, 𝘆) are the coordinates of the point.
 
- Returns what ever is returned by 𝘀𝘂𝗯.
+ Returns whatever is returned by 𝘀𝘂𝗯.
 
 =head2 $Math::Intersection::Circle::Line::near
 
@@ -450,8 +567,12 @@ $VERSION   = '1.002'; # Thursday 20 Aug 2015
 
 =item C<intersectionCircles()>
 
+=item C<intersectionCirclesArea()>
+
 =item C<intersectionCircleLine()>
 
+=item C<intersectionCircleLineArea()>
+
 =item C<intersectionLines()>
 
 =item C<intersectionLinePoint()>
@@ -459,7 +580,7 @@ $VERSION   = '1.002'; # Thursday 20 Aug 2015
 =back
 
  Optionally some useful helper functions can also be exported either by
- specifying the tag :all or by naming the required functions individually:
+ specifying the tag :𝗮𝗹𝗹 or by naming the required functions individually:
 
 =over
 
